<?php

namespace Drupal\eca_remote_request\Plugin\ECA\Condition;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\Plugin\DataType\StringData;
use Drupal\eca\Plugin\ECA\Condition\ConditionBase;
use Drupal\eca\Plugin\ECA\PluginFormTrait;

/**
 * Plugin implementation of the ECA condition "Is JSON Data".
 *
 * @EcaCondition(
 *   id = "eca_remote_request_is_json_data",
 *   label = @Translation("Is JSON Data"),
 *   description = @Translation("Test to see if the returned data is JSON formatted."),
 *   eca_version_introduced = "2.0.0",
 * )
 */
class IsJsonDataCondition extends ConditionBase {

  use PluginFormTrait;

  /**
   * {@inheritdoc}
   */
  public function evaluate(): bool {
    $tokenService = $this->tokenService;
    $config = &$this->configuration;
    $dataField = $config['data'];

    $data = $tokenService->getOrReplace($dataField);
    $result = FALSE;

    if ($data instanceof StringData) {
      $dataArray = Json::decode($data->getValue());
      if (json_last_error() === JSON_ERROR_NONE && is_array($dataArray)) {
        $result = TRUE;
      }
    }

    return $this->negationCheck($result);
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'data' => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form['data'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Data string'),
      '#description' => $this->t('Data to check if is JSON string.'),
      '#default_value' => $this->configuration['data'],
      '#required' => TRUE,
    ];
    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['data'] = $form_state->getValue('data');
    parent::submitConfigurationForm($form, $form_state);
  }

}
